Detailed Module Documentation
=============================

This section contains the complete auto-generated API documentation for all modules.

Base Classes
------------

kicadfiles.base_element module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.base_element
   :members:

kicadfiles.base_types module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.base_types
   :members:

kicadfiles.enums module
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.enums
   :members:

File Format Classes
-------------------

kicadfiles.board_layout module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.board_layout
   :members:

kicadfiles.symbol_library module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.symbol_library
   :members:

kicadfiles.footprint_library module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.footprint_library
   :members:

kicadfiles.schematic_system module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.schematic_system
   :members:

kicadfiles.project_settings module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.project_settings
   :members:

Graphics and Drawing
--------------------

kicadfiles.primitive_graphics module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.primitive_graphics
   :members:

kicadfiles.advanced_graphics module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.advanced_graphics
   :members:

kicadfiles.text_and_documents module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.text_and_documents
   :members:

PCB Components
--------------

kicadfiles.pad_and_drill module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.pad_and_drill
   :members:

kicadfiles.zone_system module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.zone_system
   :members:

Utilities
---------

kicadfiles.sexpdata module
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.sexpdata
   :members:

kicadfiles.sexpr_parser module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.sexpr_parser
   :members:

kicadfiles.json_base_element module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.json_base_element
   :members:

kicadfiles.design_rules module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.design_rules
   :members:

kicadfiles.library_tables module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: kicadfiles.library_tables
   :members: